@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 
 from ufl import *
 
@@ -11,7 +12,7 @@ class MockMesh:
         return self._ufl_id
 
     def ufl_domain(self):
-        return Domain(triangle, label="MockMesh_id_%d" % self.ufl_id(), data=self)
+        return Mesh(triangle, ufl_id=self.ufl_id(), cargo=self)
 
     def ufl_measure(self, integral_type="dx", subdomain_id="everywhere", metadata=None, subdomain_data=None):
         return Measure(integral_type, subdomain_id=subdomain_id, metadata=metadata, domain=self, subdomain_data=subdomain_data)
