@@ -25,7 +25,7 @@ from ufl.classes import (Expr, FormArgument, GeometricQuantity,
                          Jacobian, JacobianInverse, JacobianDeterminant,
                          FacetJacobian, FacetJacobianInverse, FacetJacobianDeterminant,
                          CellFacetJacobian,
-                         CellEdgeVectors, FacetEdgeVectors,
+                         ReferenceCellEdgeVectors, ReferenceFacetEdgeVectors,
                          FacetNormal, CellNormal, ReferenceNormal,
                          CellVolume, FacetArea,
                          CellOrientation, FacetOrientation, QuadratureWeight,
