@@ -1,6 +1,7 @@
 #!/usr/bin/env py.test
+# -*- coding: utf-8 -*-
 
-__authors__ = "Martin Sandve Alnes"
+__authors__ = "Martin Sandve Alnæs"
 __date__ = "2008-08-20 -- 2012-11-30"
 
 import pytest
@@ -163,5 +164,3 @@ def test_ge_produces_ufl_expr(f, g):
     # Protection from misuse in boolean python expression context:
     with pytest.raises(UFLException):
         bool(expr1)
-
-
