@@ -19,6 +19,10 @@ def test_scalar_galerkin():
                 element = FiniteElement(family, cell, p)
                 assert element.value_shape() == ()
                 assert element == eval(repr(element))
+    for p in range(1, 10):
+        for family in ("TDG", "Discontinuous Taylor"):
+            element = FiniteElement(family, interval, p)
+            assert element.value_shape() == ()
 
 
 def test_vector_galerkin():
