@@ -13,17 +13,20 @@ from six.moves import zip
 # This imports everything external code will see from ufl
 from ufl import *
 from ufl.log import error, warning
-from ufl.assertions import ufl_assert
 from ufl.tensors import as_scalar, unit_indexed_tensor, unwrap_list_tensor
 
 # TODO: Import only what you need from classes and algorithms:
 from ufl.classes import Grad, FormArgument, Zero, Indexed, FixedIndex, ListTensor
 
+
 class MockForwardAD:
+
     def __init__(self):
         self._w = ()
         self._v = ()
+
         class Obj:
+
             def __init__(self):
                 self._data = {}
         self._cd = Obj()
@@ -41,7 +44,7 @@ class MockForwardAD:
             o, = o.ufl_operands
             ngrads += 1
         if not isinstance(o, FormArgument):
-            error("Expecting gradient of a FormArgument, not %r" % (o,))
+            error("Expecting gradient of a FormArgument, not %s" % repr(o))
 
         def apply_grads(f):
             if not isinstance(f, FormArgument):
@@ -76,8 +79,8 @@ class MockForwardAD:
                 vcomp = tuple(vcomp)
             else:
                 error("Expecting argument or component of argument.")
-            ufl_assert(all(isinstance(k, FixedIndex) for k in vcomp),
-                       "Expecting only fixed indices in variation.")
+            if not all(isinstance(k, FixedIndex) for k in vcomp):
+                error("Expecting only fixed indices in variation.")
             return vval, vcomp
 
         def compute_gprimeterm(ngrads, vval, vcomp, wshape, wcomp):
@@ -98,7 +101,8 @@ class MockForwardAD:
 
             # Analyse differentiation variable coefficient
             if isinstance(w, FormArgument):
-                if not w == o: continue
+                if not w == o:
+                    continue
                 wshape = w.ufl_shape
 
                 if isinstance(v, FormArgument):
@@ -113,21 +117,23 @@ class MockForwardAD:
                             gprimesum = gprimesum + compute_gprimeterm(ngrads, vval, vcomp, wshape, wcomp)
 
                 else:
-                    ufl_assert(wshape == (), "Expecting scalar coefficient in this branch.")
+                    if wshape != ():
+                        error("Expecting scalar coefficient in this branch.")
                     # Case: d/dt [w + t v[...]]
                     wval, wcomp = w, ()
 
                     vval, vcomp = analyse_variation_argument(v)
                     gprimesum = gprimesum + compute_gprimeterm(ngrads, vval, vcomp, wshape, wcomp)
 
-            elif isinstance(w, Indexed): # This path is tested in unit tests, but not actually used?
+            elif isinstance(w, Indexed):  # This path is tested in unit tests, but not actually used?
                 # Case: d/dt [w[...] + t v[...]]
                 # Case: d/dt [w[...] + t v]
                 wval, wcomp = w.ufl_operands
-                if not wval == o: continue
+                if not wval == o:
+                    continue
                 assert isinstance(wval, FormArgument)
-                ufl_assert(all(isinstance(k, FixedIndex) for k in wcomp),
-                           "Expecting only fixed indices in differentiation variable.")
+                if not all(isinstance(k, FixedIndex) for k in wcomp):
+                    error("Expecting only fixed indices in differentiation variable.")
                 wshape = wval.ufl_shape
 
                 vval, vcomp = analyse_variation_argument(v)
@@ -149,8 +155,9 @@ class MockForwardAD:
                 # Make sure we have a tuple to match the self._v tuple
                 if not isinstance(oprimes, tuple):
                     oprimes = (oprimes,)
-                    ufl_assert(len(oprimes) == len(self._v), "Got a tuple of arguments, "+\
-                                   "expecting a matching tuple of coefficient derivatives.")
+                    if len(oprimes) != len(self._v):
+                        error("Got a tuple of arguments, "
+                              "expecting a matching tuple of coefficient derivatives.")
 
                 # Compute dg/dw_j = dg/dw_h : v.
                 # Since we may actually have a tuple of oprimes and vs in a
@@ -177,10 +184,11 @@ def test_unit_tensor(self):
     E22_10, ii = unit_indexed_tensor((2, 2), (1, 0))
     # TODO: Evaluate and assert values
 
+
 def test_unwrap_list_tensor(self):
     lt = as_tensor((1, 2))
     expected = [((0,), 1),
-                ((1,), 2),]
+                ((1,), 2), ]
     comp = unwrap_list_tensor(lt)
     assert comp == expected
 
@@ -188,7 +196,7 @@ def test_unwrap_list_tensor(self):
     expected = [((0, 0), 1),
                 ((0, 1), 2),
                 ((1, 0), 3),
-                ((1, 1), 4),]
+                ((1, 1), 4), ]
     comp = unwrap_list_tensor(lt)
     assert comp == expected
 
@@ -201,10 +209,11 @@ def test_unwrap_list_tensor(self):
                 ((1, 0, 0), 11),
                 ((1, 0, 1), 12),
                 ((1, 1, 0), 13),
-                ((1, 1, 1), 14),]
+                ((1, 1, 1), 14), ]
     comp = unwrap_list_tensor(lt)
     assert comp == expected
 
+
 def test__forward_coefficient_ad__grad_of_scalar_coefficient(self):
     U = FiniteElement("CG", triangle, 1)
     u = Coefficient(U)
@@ -228,6 +237,7 @@ def test__forward_coefficient_ad__grad_of_scalar_coefficient(self):
     assert g == f
     assert dg == df
 
+
 def test__forward_coefficient_ad__grad_of_vector_coefficient(self):
     V = VectorElement("CG", triangle, 1)
     v = Coefficient(V)
@@ -251,6 +261,7 @@ def test__forward_coefficient_ad__grad_of_vector_coefficient(self):
     assert g == f
     assert dg == df
 
+
 def test__forward_coefficient_ad__grad_of_vector_coefficient__with_component_variation(self):
     V = VectorElement("CG", triangle, 1)
     v = Coefficient(V)
@@ -263,9 +274,9 @@ def test__forward_coefficient_ad__grad_of_vector_coefficient__with_component_var
     mad._w = (v[0],)
     mad._v = (dv[1],)
     f = grad(v)
-    df = grad(as_vector((dv[1], 0))) # Mathematically this would be the natural result
+    df = grad(as_vector((dv[1], 0)))  # Mathematically this would be the natural result
     j, k = indices(2)
-    df = as_tensor(Identity(2)[0, j]*grad(dv)[1, k], (j, k)) # Actual representation should have grad right next to dv
+    df = as_tensor(Identity(2)[0, j]*grad(dv)[1, k], (j, k))  # Actual representation should have grad right next to dv
     g, dg = mad.grad(f)
     if 0:
         print(('\nf    ', f))
@@ -278,7 +289,7 @@ def test__forward_coefficient_ad__grad_of_vector_coefficient__with_component_var
     assert g == f
     self.assertEqual((inner(dg, dg)*dx).signature(),
                      (inner(df, df)*dx).signature())
-    #assert dg == df # Expected to fail because of different index numbering
+    # assert dg == df # Expected to fail because of different index numbering
 
     # Multiple components of variation:
     # grad(grad(c))[0,1,:,:] -> grad(grad(dc))[1,0,:,:]
@@ -289,9 +300,9 @@ def test__forward_coefficient_ad__grad_of_vector_coefficient__with_component_var
     df = grad(as_vector((dv[1], dv[0])))
     # Actual representation should have grad right next to dv:
     j0, k0 = indices(2)
-    j1, k1 = indices(2) # Using j0,k0 for both terms gives different signature
+    j1, k1 = indices(2)  # Using j0,k0 for both terms gives different signature
     df = (as_tensor(Identity(2)[0, j0]*grad(dv)[1, k0], (j0, k0))
-        + as_tensor(Identity(2)[1, j1]*grad(dv)[0, k1], (j1, k1)))
+          + as_tensor(Identity(2)[1, j1]*grad(dv)[0, k1], (j1, k1)))
     g, dg = mad.grad(f)
     print(('\nf    ', f))
     print(('df   ', df))
@@ -303,7 +314,8 @@ def test__forward_coefficient_ad__grad_of_vector_coefficient__with_component_var
     assert g == f
     self.assertEqual((inner(dg, dg)*dx).signature(),
                      (inner(df, df)*dx).signature())
-    #assert dg == df # Expected to fail because of different index numbering
+    # assert dg == df # Expected to fail because of different index numbering
+
 
 def test__forward_coefficient_ad__grad_of_vector_coefficient__with_component_variation_in_list(self):
     V = VectorElement("CG", triangle, 1)
@@ -317,9 +329,9 @@ def test__forward_coefficient_ad__grad_of_vector_coefficient__with_component_var
     mad._w = (v,)
     mad._v = (as_vector((dv[1], 0)),)
     f = grad(v)
-    df = grad(as_vector((dv[1], 0))) # Mathematically this would be the natural result
+    df = grad(as_vector((dv[1], 0)))  # Mathematically this would be the natural result
     j, k = indices(2)
-    df = as_tensor(Identity(2)[0, j]*grad(dv)[1, k], (j, k)) # Actual representation should have grad right next to dv
+    df = as_tensor(Identity(2)[0, j]*grad(dv)[1, k], (j, k))  # Actual representation should have grad right next to dv
     g, dg = mad.grad(f)
     if 0:
         print(('\nf    ', f))
@@ -332,7 +344,7 @@ def test__forward_coefficient_ad__grad_of_vector_coefficient__with_component_var
     assert g == f
     self.assertEqual((inner(dg, dg)*dx).signature(),
                      (inner(df, df)*dx).signature())
-    #assert dg == df # Expected to fail because of different index numbering
+    # assert dg == df # Expected to fail because of different index numbering
 
     # Multiple components of variation:
     # grad(grad(c))[0,1,:,:] -> grad(grad(dc))[1,0,:,:]
@@ -343,9 +355,9 @@ def test__forward_coefficient_ad__grad_of_vector_coefficient__with_component_var
     df = grad(as_vector((dv[1], dv[0])))
     # Actual representation should have grad right next to dv:
     j0, k0 = indices(2)
-    j1, k1 = indices(2) # Using j0,k0 for both terms gives different signature
+    j1, k1 = indices(2)  # Using j0,k0 for both terms gives different signature
     df = (as_tensor(Identity(2)[0, j0]*grad(dv)[1, k0], (j0, k0))
-        + as_tensor(Identity(2)[1, j1]*grad(dv)[0, k1], (j1, k1)))
+          + as_tensor(Identity(2)[1, j1]*grad(dv)[0, k1], (j1, k1)))
     g, dg = mad.grad(f)
     print(('\nf    ', f))
     print(('df   ', df))
@@ -357,7 +369,7 @@ def test__forward_coefficient_ad__grad_of_vector_coefficient__with_component_var
     assert g == f
     self.assertEqual((inner(dg, dg)*dx).signature(),
                      (inner(df, df)*dx).signature())
-    #assert dg == df # Expected to fail because of different index numbering
+    # assert dg == df # Expected to fail because of different index numbering
 
 
 def test__forward_coefficient_ad__grad_of_tensor_coefficient(self):
@@ -383,6 +395,7 @@ def test__forward_coefficient_ad__grad_of_tensor_coefficient(self):
     assert g == f
     assert dg == df
 
+
 def test__forward_coefficient_ad__grad_of_tensor_coefficient__with_component_variation(self):
     W = TensorElement("CG", triangle, 1)
     w = Coefficient(W)
@@ -397,11 +410,11 @@ def test__forward_coefficient_ad__grad_of_tensor_coefficient__with_component_var
     mad._w = (w[wc],)
     mad._v = (dw[dwc],)
     f = grad(w)
-    df = grad(as_matrix(((0, 0), (dw[dwc], 0)))) # Mathematically this is it.
+    df = grad(as_matrix(((0, 0), (dw[dwc], 0))))  # Mathematically this is it.
     i, j, k = indices(3)
     E = outer(Identity(2)[wc[0], i], Identity(2)[wc[1], j])
     Ddw = grad(dw)[dwc + (k,)]
-    df = as_tensor(E*Ddw, (i, j, k)) # Actual representation should have grad next to dv
+    df = as_tensor(E*Ddw, (i, j, k))  # Actual representation should have grad next to dv
     g, dg = mad.grad(f)
     if 0:
         print(('\nf    ', f))
@@ -414,4 +427,4 @@ def test__forward_coefficient_ad__grad_of_tensor_coefficient__with_component_var
     assert g == f
     self.assertEqual((inner(dg, dg)*dx).signature(),
                      (inner(df, df)*dx).signature())
-    #assert dg == df # Expected to fail because of different index numbering
+    # assert dg == df # Expected to fail because of different index numbering
