@@ -157,19 +157,21 @@ def test_tr(self, A):
     self.assertEqualValues(C, D)
 
 
-def xtest_det(self, A):
+def test_det(self, A):
+    dims = (0, 1)
     C = det(A)
-    D = zero()  # FIXME: Add expected value here
+    D = sum((-A[i, 0]*A[0, i] if i !=0 else A[i-1, -1]*A[i, 0]) for i in dims)
     self.assertEqualValues(C, D)
 
 
-def xtest_cofac(self, A):
+def test_cofac(self, A):
     C = cofac(A)
-    D = 0*C  # FIXME: Add expected value here
+    D = as_matrix([[(-A[i,j] if i != j else A[i,j]) for j in (-1,0)] for i in (-1,0)])
     self.assertEqualValues(C, D)
 
 
 def xtest_inv(self, A):
     C = inv(A)
-    D = 0*C  # FIXME: Add expected value here
+    detA = sum((-A[i, 0]*A[0, i] if i !=0 else A[i-1, -1]*A[i, 0]) for i in (0,1))
+    D = as_matrix([[(-A[i,j] if i != j else A[i,j]) for j in (-1,0)] for i in (-1,0)]) / detA  # FIXME: Test fails probably due to integer division
     self.assertEqualValues(C, D)
