@@ -9,8 +9,7 @@ notation close to the mathematical one.
 This Python module contains the language as well as algorithms to work
 with it.
 
-* To import the language, type
-::
+* To import the language, type::
 
     from ufl import *
 
@@ -77,6 +76,7 @@ A very brief overview of the language contents follows:
     - VectorElement
     - TensorElement
     - EnrichedElement
+    - NodalEnrichedElement
     - RestrictedElement
     - TensorProductElement
     - HDivElement
@@ -120,6 +120,7 @@ A very brief overview of the language contents follows:
     - FacetNormal
     - CellNormal
     - CellVolume
+    - CellDiameter
     - Circumradius
     - MinCellEdgeLength
     - MaxCellEdgeLength
@@ -241,7 +242,9 @@ A very brief overview of the language contents follows:
 # Modified by Lawrence Mitchell, 2014
 # Modified by Massimiliano Leoni, 2016
 
-__version__ = "2016.2.0"
+import pkg_resources
+
+__version__ = pkg_resources.get_distribution("fenics-ufl").version
 
 ########## README
 # Imports here should be what the user sees when doing "from ufl import *",
@@ -265,7 +268,7 @@ from ufl.domain import as_domain, AbstractDomain, Mesh, MeshView, TensorProductM
 from ufl.geometry import (
     SpatialCoordinate,
     FacetNormal, CellNormal,
-    CellVolume, Circumradius, MinCellEdgeLength, MaxCellEdgeLength,
+    CellVolume, CellDiameter, Circumradius, MinCellEdgeLength, MaxCellEdgeLength,
     FacetArea, MinFacetEdgeLength, MaxFacetEdgeLength,
     Jacobian, JacobianDeterminant, JacobianInverse
     )
@@ -276,7 +279,7 @@ from ufl.sobolevspace import L2, H1, H2, HDiv, HCurl
 # Finite elements classes
 from ufl.finiteelement import FiniteElementBase, FiniteElement, \
     MixedElement, VectorElement, TensorElement, EnrichedElement, \
-    RestrictedElement, TensorProductElement, \
+    NodalEnrichedElement, RestrictedElement, TensorProductElement, \
     HDivElement, HCurlElement, BrokenElement, \
     FacetElement, InteriorElement
 
@@ -370,13 +373,14 @@ __all__ = as_native_strings([
     'as_domain', 'AbstractDomain', 'Mesh', 'MeshView', 'TensorProductMesh',
     'L2', 'H1', 'H2', 'HCurl', 'HDiv',
     'SpatialCoordinate',
-    'CellVolume', 'Circumradius', 'MinCellEdgeLength', 'MaxCellEdgeLength',
+    'CellVolume', 'CellDiameter', 'Circumradius',
+    'MinCellEdgeLength', 'MaxCellEdgeLength',
     'FacetArea', 'MinFacetEdgeLength', 'MaxFacetEdgeLength',
     'FacetNormal', 'CellNormal',
     'Jacobian', 'JacobianDeterminant', 'JacobianInverse',
     'FiniteElementBase', 'FiniteElement',
     'MixedElement', 'VectorElement', 'TensorElement', 'EnrichedElement',
-    'RestrictedElement', 'TensorProductElement',
+    'NodalEnrichedElement', 'RestrictedElement', 'TensorProductElement',
     'HDivElement', 'HCurlElement',
     'BrokenElement', 'FacetElement', 'InteriorElement',
     'register_element', 'show_elements',
@@ -416,4 +420,4 @@ __all__ = as_native_strings([
     'quadrilateral', 'hexahedron', 'facet',
     'i', 'j', 'k', 'l', 'p', 'q', 'r', 's',
     'e', 'pi',
-    ])
+])
