@@ -23,6 +23,7 @@ raw input form given by a user."""
 from itertools import chain
 
 from ufl.log import error, info
+from ufl.utils.sequences import max_degree
 
 from ufl.classes import GeometricFacetQuantity, Coefficient, Form
 from ufl.corealg.traversal import traverse_unique_terminals
@@ -30,7 +31,6 @@ from ufl.algorithms.analysis import extract_coefficients, extract_sub_elements,
 from ufl.algorithms.formdata import FormData
 from ufl.algorithms.formtransformations import compute_form_arities
 from ufl.algorithms.check_arities import check_form_arity
-from ufl.algorithms.elementtransformations import reconstruct_element
 
 # These are the main symbolic processing steps:
 from ufl.algorithms.apply_function_pullbacks import apply_function_pullbacks
@@ -56,7 +56,7 @@ def _auto_select_degree(elements):
     """
     # Use max degree of all elements, at least 1 (to work with
     # Lagrange elements)
-    return max({e.degree() for e in elements} - {None} | {1})
+    return max_degree({e.degree() for e in elements} - {None} | {1})
 
 
 def _compute_element_mapping(form):
@@ -103,9 +103,7 @@ def _compute_element_mapping(form):
 
         # Reconstruct element and add to map
         if reconstruct:
-            element_mapping[element] = reconstruct_element(element,
-                                                           element.family(),
-                                                           cell, degree)
+            element_mapping[element] = element.reconstruct(cell=cell, degree=degree)
         else:
             element_mapping[element] = element
 
