@@ -23,7 +23,7 @@
 from ufl.utils.py23 import as_native_strings
 from ufl.log import error
 from ufl.finiteelement import FiniteElement, VectorElement, TensorElement, \
-    MixedElement, EnrichedElement
+    MixedElement, EnrichedElement, NodalEnrichedElement
 
 __all__ = as_native_strings(['increase_order', 'tear'])
 
@@ -38,7 +38,7 @@ def change_regularity(element, family):
     For a given finite element, return the corresponding space
     specified by 'family'.
     """
-    return _change_family(element, family)
+    return element.reconstruct(family=family)
 
 
 def tear(element):
@@ -46,42 +46,21 @@ def tear(element):
     return change_regularity(element, "DG")
 
 
-def reconstruct_element(element, family, cell, degree):
-    if isinstance(element, FiniteElement):
-        return FiniteElement(family, cell, degree)
-    elif isinstance(element, VectorElement):
-        return VectorElement(family, cell, degree, dim=element.value_shape()[0])
-    elif isinstance(element, TensorElement):
-        return TensorElement(family, cell, degree, shape=element.value_shape())
-    else:
-        error("Element reconstruction is only done to stay compatible"
-              " with hacks in DOLFIN. Not expecting a %s" % repr(element))
-
-
 def _increase_degree(element, degree_rise):
     if isinstance(element, (FiniteElement, VectorElement, TensorElement)):
-        return reconstruct_element(element, element.family(), element.cell(),
-                                   element.degree() + degree_rise)
+        # Can't increase degree for reals
+        if element.family() == "Real":
+            return element
+        return element.reconstruct(degree=(element.degree() + degree_rise))
     elif isinstance(element, MixedElement):
         return MixedElement([_increase_degree(e, degree_rise)
                              for e in element.sub_elements()])
     elif isinstance(element, EnrichedElement):
         return EnrichedElement([_increase_degree(e, degree_rise)
                                 for e in element.sub_elements()])
-    else:
-        error("Element reconstruction is only done to stay compatible"
-              " with hacks in DOLFIN. Not expecting a %s" % repr(element))
-
-
-def _change_family(element, family):
-    if isinstance(element, (FiniteElement, VectorElement, TensorElement)):
-        return reconstruct_element(element, family, element.cell(), element.degree())
-    elif isinstance(element, MixedElement):
-        return MixedElement([_change_family(e, family)
-                             for e in element.sub_elements()])
-    elif isinstance(element, EnrichedElement):
-        return EnrichedElement([_change_family(e, family)
-                                for e in element.sub_elements()])
+    elif isinstance(element, NodalEnrichedElement):
+        return NodalEnrichedElement([_increase_degree(e, degree_rise)
+                                     for e in element.sub_elements()])
     else:
         error("Element reconstruction is only done to stay compatible"
               " with hacks in DOLFIN. Not expecting a %s" % repr(element))
