@@ -3,7 +3,7 @@
 for expanding free indices in expressions to explicit fixed
 indices only."""
 
-# Copyright (C) 2008-2015 Martin Sandve Alnæs
+# Copyright (C) 2008-2016 Martin Sandve Alnæs
 #
 # This file is part of UFL.
 #
@@ -27,11 +27,7 @@ from six.moves import xrange as range
 
 from ufl.log import error
 from ufl.utils.stacks import Stack, StackDict
-from ufl.assertions import ufl_assert
-from ufl.finiteelement import TensorElement
-from ufl.classes import Expr, Terminal, ListTensor, IndexSum, Indexed, FormArgument
-from ufl.tensors import as_tensor, ComponentTensor
-from ufl.permutation import compute_indices
+from ufl.classes import Terminal, ListTensor
 from ufl.constantvalue import Zero
 from ufl.core.multiindex import Index, FixedIndex, MultiIndex
 from ufl.differentiation import Grad
@@ -55,7 +51,8 @@ class IndexExpander(ReuseTransformer):
     def terminal(self, x):
         if x.ufl_shape:
             c = self.component()
-            ufl_assert(len(x.ufl_shape) == len(c), "Component size mismatch.")
+            if len(x.ufl_shape) != len(c):
+                error("Component size mismatch.")
             return x[c]
         return x
 
@@ -69,17 +66,20 @@ class IndexExpander(ReuseTransformer):
 
             # Get component
             c = self.component()
-            ufl_assert(r == len(c), "Component size mismatch.")
+            if r != len(c):
+                error("Component size mismatch.")
 
             # Map it through an eventual symmetry mapping
             s = e.symmetry()
             c = s.get(c, c)
-            ufl_assert(r == len(c), "Component size mismatch after symmetry mapping.")
+            if r != len(c):
+                error("Component size mismatch after symmetry mapping.")
 
             return x[c]
 
     def zero(self, x):
-        ufl_assert(len(x.ufl_shape) == len(self.component()), "Component size mismatch.")
+        if len(x.ufl_shape) != len(self.component()):
+            error("Component size mismatch.")
 
         s = set(x.ufl_free_indices) - set(i.count() for i in self._index2value.keys())
         if s:
@@ -91,7 +91,8 @@ class IndexExpander(ReuseTransformer):
     def scalar_value(self, x):
         if len(x.ufl_shape) != len(self.component()):
             self.print_visit_stack()
-        ufl_assert(len(x.ufl_shape) == len(self.component()), "Component size mismatch.")
+        if len(x.ufl_shape) != len(self.component()):
+            error("Component size mismatch.")
 
         s = set(x.ufl_free_indices) - set(i.count() for i in self._index2value.keys())
         if s:
@@ -99,19 +100,40 @@ class IndexExpander(ReuseTransformer):
 
         return x._ufl_class_(x.value())
 
+    def conditional(self, x):
+        c, t, f = x.ufl_operands
+
+        # Not accepting nonscalars in condition
+        if c.ufl_shape != ():
+            error("Not expecting tensor in condition.")
+
+        # Conditional may be indexed, push empty component
+        self._components.push(())
+        c = self.visit(c)
+        self._components.pop()
+
+        # Keep possibly non-scalar components for values
+        t = self.visit(t)
+        f = self.visit(f)
+
+        return self.reuse_if_possible(x, c, t, f)
+
     def division(self, x):
         a, b = x.ufl_operands
 
         # Not accepting nonscalars in division anymore
-        ufl_assert(a.ufl_shape == (), "Not expecting tensor in division.")
-        ufl_assert(self.component() == (), "Not expecting component in division.")
+        if a.ufl_shape != ():
+            error("Not expecting tensor in division.")
+        if self.component() != ():
+            error("Not expecting component in division.")
 
-        ufl_assert(b.ufl_shape == (), "Not expecting division by tensor.")
+        if b.ufl_shape != ():
+            error("Not expecting division by tensor.")
         a = self.visit(a)
 
-        #self._components.push(())
+        # self._components.push(())
         b = self.visit(b)
-        #self._components.pop()
+        # self._components.pop()
 
         return self.reuse_if_possible(x, a, b)
 
@@ -150,16 +172,16 @@ class IndexExpander(ReuseTransformer):
         self._components.push(self._multi_index_values(ii))
 
         # Hide index values (doing this is not correct behaviour)
-        #for i in ii:
-        #    if isinstance(i, Index):
-        #        self._index2value.push(i, None)
+        # for i in ii:
+        #     if isinstance(i, Index):
+        #         self._index2value.push(i, None)
 
         result = self.visit(A)
 
         # Un-hide index values
-        #for i in ii:
-        #    if isinstance(i, Index):
-        #        self._index2value.pop()
+        # for i in ii:
+        #     if isinstance(i, Index):
+        #         self._index2value.pop()
 
         # Reset component
         self._components.pop()
@@ -169,11 +191,13 @@ class IndexExpander(ReuseTransformer):
         # This function evaluates the tensor expression
         # with indices equal to the current component tuple
         expression, indices = x.ufl_operands
-        ufl_assert(expression.ufl_shape == (), "Expecting scalar base expression.")
+        if expression.ufl_shape != ():
+            error("Expecting scalar base expression.")
 
         # Update index map with component tuple values
         comp = self.component()
-        ufl_assert(len(indices) == len(comp), "Index/component mismatch.")
+        if len(indices) != len(comp):
+            error("Index/component mismatch.")
         for i, v in zip(indices.indices(), comp):
             self._index2value.push(i, v)
         self._components.push(())
@@ -200,8 +224,8 @@ class IndexExpander(ReuseTransformer):
 
     def grad(self, x):
         f, = x.ufl_operands
-        ufl_assert(isinstance(f, (Terminal, Grad)),
-                   "Expecting expand_derivatives to have been applied.")
+        if not isinstance(f, (Terminal, Grad)):
+            error("Expecting expand_derivatives to have been applied.")
         # No need to visit child as long as it is on the form [Grad]([Grad](terminal))
         return x[self.component()]
 
@@ -215,5 +239,5 @@ def purge_list_tensors(expr):
     expressions to use their components directly.
     Will usually increase the size of the expression."""
     if any(isinstance(subexpr, ListTensor) for subexpr in unique_pre_traversal(expr)):
-        return expand_indices(expr) # TODO: Only expand what's necessary to get rid of list tensors
+        return expand_indices(expr)  # TODO: Only expand what's necessary to get rid of list tensors
     return expr
