@@ -20,15 +20,13 @@
 #
 # Modified by Anders Logg, 2008.
 
-#import six
 from ufl.utils.formatting import lstr, tstr, estr
 
 
-# @six.python_2_unicode_compatible
 class FormData(object):
-    """
-    Class collecting various information extracted from a Form by
+    """Class collecting various information extracted from a Form by
     calling preprocess.
+
     """
 
     def __init__(self):
@@ -60,7 +58,6 @@ class FormData(object):
         return tstr(geometry + subdomains + functions)
 
 
-# @six.python_2_unicode_compatible
 class ExprData(object):
     """
     Class collecting various information extracted from a Expr by
