@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 """A collection of utility algorithms for handling UFL files."""
 
-# Copyright (C) 2008-2015 Martin Sandve Alnæs
+# Copyright (C) 2008-2016 Martin Sandve Alnæs
 #
 # This file is part of UFL.
 #
@@ -21,23 +21,26 @@
 # Modified by Anders Logg, 2008-2009.
 # Modified by Marie E. Rognes, 2011.
 
+import six
+import io
 import os
 import re
+import ufl
 from ufl.log import error, warning
 from ufl.utils.sorting import sorted_by_key
-from ufl.assertions import ufl_assert
 from ufl.form import Form
 from ufl.finiteelement import FiniteElementBase
 from ufl.core.expr import Expr
 from ufl.argument import Argument
 from ufl.coefficient import Coefficient
 
+
 class FileData(object):
     def __init__(self):
-        self.elements     = []
+        self.elements = []
         self.coefficients = []
-        self.expressions  = []
-        self.forms        = []
+        self.expressions = []
+        self.forms = []
         self.object_names = {}
         self.object_by_name = {}
         self.reserved_objects = {}
@@ -47,28 +50,53 @@ class FileData(object):
                     self.object_names or self.object_by_name or self.reserved_objects)
     __nonzero__ = __bool__
 
-infostring = """An exception occured during evaluation of form file.
-To help you find the location of the error, a temporary script
-'%s'
-has been created and will now be executed with debug output enabled:"""
 
-def replace_include_statements(code):
+def read_lines_decoded(fn):
+    r = re.compile(b".*coding: *([^ ]+)")
+    if six.PY3:
+        def match(line):
+            return r.match(line, re.ASCII)
+    else:
+        def match(line):
+            return r.match(line)
+
+    # First read lines as bytes
+    with io.open(fn, "rb") as f:
+        lines = f.readlines()
+
+    # Check for coding: in the first two lines
+    for i in range(min(2, len(lines))):
+        m = match(lines[i])
+        if m:
+            encoding, = m.groups()
+            # Drop encoding line
+            lines = lines[:i] + lines[i+1:]
+            break
+    else:
+        # Default to utf-8 (works for ascii files
+        # as well, default for python files in py3)
+        encoding = "utf-8"
+
+    # Decode all lines
+    lines = [line.decode(encoding=encoding) for line in lines]
+    return lines
+
+
+def replace_include_statements(lines):
     "Replace '#include foo.ufl' statements with contents of foo.ufl."
-    if "#include" in code:
-        lines = code.split("\n")
-        newlines = []
-        regexp = re.compile(r"^#include (.*)$")
-        for l in lines:
-            m = regexp.search(l)
-            if m:
-                fn = m.groups()[0]
-                newlines.append("# --- begin %s" % fn)
-                newlines.extend(open(fn).readlines())
-                newlines.append("# --- end %s" % fn)
-            else:
-                newlines.append(l)
-        return "\n".join(l.rstrip() for l in newlines)
-    return code
+    r = re.compile(r"^#include (.*)$")
+    newlines = []
+    for l in lines:
+        m = r.search(l)
+        if m:
+            fn = m.groups()[0]
+            newlines.append("# --- begin %s\n" % fn)
+            newlines.extend(read_lines_decoded(fn))
+            newlines.append("# --- end %s\n" % fn)
+        else:
+            newlines.append(l)
+    return newlines
+
 
 def read_ufl_file(filename):
     "Read a .ufl file, handling file extension, file existance, and #include replacement."
@@ -76,29 +104,36 @@ def read_ufl_file(filename):
         filename = filename + ".ufl"
     if not os.path.exists(filename):
         error("File '%s' doesn't exist." % filename)
-    with open(filename) as f:
-        code = replace_include_statements(f.read())
+    lines = read_lines_decoded(filename)
+    lines = replace_include_statements(lines)
+    code = "".join(lines)
     return code
 
+
+infostring = """\
+An exception occured during evaluation of .ufl file.
+If you need to debug it as a python script, rename it to .py
+and add the lines
+
+    from ufl import *
+    set_level(DEBUG)
+
+at the top then run with python.
+"""
+
+
 def execute_ufl_code(uflcode, filename):
     # Execute code
     namespace = {}
+    namespace.update(vars(ufl))
     try:
-        pycode = "# -*- coding: utf-8 -*-\nfrom ufl import *\n" + uflcode
-        exec(pycode, namespace)
-    except:
-        # Dump python code for debugging if this fails
-        basename = os.path.splitext(os.path.basename(filename))[0]
-        basename = "%s_debug" % basename
-        pyname = "%s.py" % basename
-        pycode = "#!/usr/bin/env python\n# -*- coding: utf-8 -*-\nfrom ufl import *\nset_level(DEBUG)\n" + uflcode
-        with open(pyname, "w") as f:
-            f.write(pycode)
-        warning(infostring % pyname)
-        m = __import__(basename)
-        error("An error occured, aborting load_forms.")
+        exec(uflcode, namespace)
+    except Exception as e:
+        warning(infostring)
+        raise e
     return namespace
 
+
 def interpret_ufl_namespace(namespace):
     "Takes a namespace dict from an executed ufl file and converts it to a FileData object."
     # Object to hold all returned data
@@ -110,7 +145,7 @@ def interpret_ufl_namespace(namespace):
     # and not just between objects with different values.
     for name, value in sorted_by_key(namespace):
         # Store objects by reserved name OR instance id
-        reserved_names = ("unknown",) # Currently only one reserved name
+        reserved_names = ("unknown",)  # Currently only one reserved name
         if name in reserved_names:
             # Store objects with reserved names
             ufd.reserved_objects[name] = value
@@ -118,14 +153,16 @@ def interpret_ufl_namespace(namespace):
             ufd.object_names[name] = value
             ufd.object_by_name[name] = value
         elif isinstance(value, (FiniteElementBase, Coefficient, Argument, Form, Expr)):
-            # Store instance <-> name mappings for important objects without a reserved name
+            # Store instance <-> name mappings for important objects
+            # without a reserved name
             ufd.object_names[id(value)] = name
             ufd.object_by_name[name] = value
 
     # Get list of exported forms
     forms = namespace.get("forms")
     if forms is None:
-        # Get forms from object_by_name, which has already mapped tuple->Form where needed
+        # Get forms from object_by_name, which has already mapped
+        # tuple->Form where needed
         def get_form(name):
             form = ufd.object_by_name.get(name)
             return form if isinstance(form, Form) else None
@@ -143,10 +180,10 @@ def interpret_ufl_namespace(namespace):
     ufd.forms = forms
 
     # Validate types
-    ufl_assert(isinstance(ufd.forms, (list, tuple)),
-        "Expecting 'forms' to be a list or tuple, not '%s'." % type(ufd.forms))
-    ufl_assert(all(isinstance(a, Form) for a in ufd.forms),
-        "Expecting 'forms' to be a list of Form instances.")
+    if not isinstance(ufd.forms, (list, tuple)):
+        error("Expecting 'forms' to be a list or tuple, not '%s'." % type(ufd.forms))
+    if not all(isinstance(a, Form) for a in ufd.forms):
+        error("Expecting 'forms' to be a list of Form instances.")
 
     # Get list of exported elements
     elements = namespace.get("elements")
@@ -156,37 +193,38 @@ def interpret_ufl_namespace(namespace):
     ufd.elements = elements
 
     # Validate types
-    ufl_assert(isinstance(ufd.elements,  (list, tuple)),
-        "Expecting 'elements' to be a list or tuple, not '%s'." % type(ufd.elements))
-    ufl_assert(all(isinstance(e, FiniteElementBase) for e in ufd.elements),
-        "Expecting 'elements' to be a list of FiniteElementBase instances.")
+    if not isinstance(ufd.elements, (list, tuple)):
+        error("Expecting 'elements' to be a list or tuple, not '%s'." % type(ufd.elements))
+    if not all(isinstance(e, FiniteElementBase) for e in ufd.elements):
+        error("Expecting 'elements' to be a list of FiniteElementBase instances.")
 
     # Get list of exported coefficients
-    # TODO: Temporarily letting 'coefficients' override 'functions', but allow 'functions' for compatibility
+    # TODO: Temporarily letting 'coefficients' override 'functions',
+    # but allow 'functions' for compatibility
     functions = namespace.get("functions", [])
     if functions:
         warning("Deprecation warning: Rename 'functions' to 'coefficients' to export coefficients.")
     ufd.coefficients = namespace.get("coefficients", functions)
-    #ufd.coefficients = namespace.get("coefficients", [])
 
     # Validate types
-    ufl_assert(isinstance(ufd.coefficients, (list, tuple)),
-        "Expecting 'coefficients' to be a list or tuple, not '%s'." % type(ufd.coefficients))
-    ufl_assert(all(isinstance(e, Coefficient) for e in ufd.coefficients),
-        "Expecting 'coefficients' to be a list of Coefficient instances.")
+    if not isinstance(ufd.coefficients, (list, tuple)):
+        error("Expecting 'coefficients' to be a list or tuple, not '%s'." % type(ufd.coefficients))
+    if not all(isinstance(e, Coefficient) for e in ufd.coefficients):
+        error("Expecting 'coefficients' to be a list of Coefficient instances.")
 
     # Get list of exported expressions
     ufd.expressions = namespace.get("expressions", [])
 
     # Validate types
-    ufl_assert(isinstance(ufd.expressions, (list, tuple)),
-        "Expecting 'expressions' to be a list or tuple, not '%s'." % type(ufd.expressions))
-    ufl_assert(all(isinstance(e, Expr) for e in ufd.expressions),
-        "Expecting 'expressions' to be a list of Expr instances.")
+    if not isinstance(ufd.expressions, (list, tuple)):
+        error("Expecting 'expressions' to be a list or tuple, not '%s'." % type(ufd.expressions))
+    if not all(isinstance(e, Expr) for e in ufd.expressions):
+        error("Expecting 'expressions' to be a list of Expr instances.")
 
     # Return file data
     return ufd
 
+
 def load_ufl_file(filename):
     "Load a .ufl file with elements, coefficients and forms."
     # Read code from file and execute it
@@ -194,6 +232,7 @@ def load_ufl_file(filename):
     namespace = execute_ufl_code(uflcode, filename)
     return interpret_ufl_namespace(namespace)
 
+
 def load_forms(filename):
     "Return a list of all forms in a file."
     ufd = load_ufl_file(filename)
