@@ -1,7 +1,8 @@
+# -*- coding: utf-8 -*-
 """This module defines utilities for transforming
 complete Forms into new related Forms."""
 
-# Copyright (C) 2008-2014 Martin Sandve Alnes
+# Copyright (C) 2008-2016 Martin Sandve Alnæs
 #
 # This file is part of UFL.
 #
@@ -25,15 +26,13 @@ complete Forms into new related Forms."""
 from six import iteritems
 from six.moves import xrange as range
 
-from ufl.common import product
 from ufl.log import error, warning, debug
-from ufl.assertions import ufl_assert
 
 # All classes:
+from ufl.core.expr import ufl_err_str
 from ufl.argument import Argument
 from ufl.coefficient import Coefficient
 from ufl.constantvalue import Zero
-from ufl.algebra import Sum
 
 # Other algorithms:
 from ufl.algorithms.map_integrands import map_integrands
@@ -72,7 +71,7 @@ class PartExtracter(Transformer):
         """The default is a nonlinear operator not accepting any
         Arguments among its children."""
         if _expr_has_terminal_types(x, Argument):
-            error("Found Argument in %s, this is an invalid expression." % repr(x))
+            error("Found Argument in %s, this is an invalid expression." % ufl_err_str(x))
         return (x, set())
 
     # Terminals that are not Variables or Arguments behave as default
@@ -164,7 +163,7 @@ class PartExtracter(Transformer):
 
         # 3. Return the terms that provide the biggest set
         most_provided = frozenset()
-        for (provideds, parts) in iteritems(parts_that_provide): # TODO: Just sort instead?
+        for (provideds, parts) in iteritems(parts_that_provide):  # TODO: Just sort instead?
 
             # Throw error if size of sets are equal (and not zero)
             if len(provideds) == len(most_provided) and len(most_provided):
@@ -220,7 +219,7 @@ class PartExtracter(Transformer):
 
         # Check for Arguments in the denominator
         if _expr_has_terminal_types(denominator, Argument):
-            error("Found Argument in denominator of %s , this is an invalid expression." % repr(x))
+            error("Found Argument in denominator of %s , this is an invalid expression." % ufl_err_str(x))
 
         # Visit numerator
         numerator_parts, provides = self.visit(numerator)
@@ -311,6 +310,7 @@ class PartExtracter(Transformer):
 
         return (x, most_provides)
 
+
 def compute_form_with_arity(form, arity, arguments=None):
     """Compute parts of form of given arity."""
 
@@ -332,6 +332,7 @@ def compute_form_with_arity(form, arity, arguments=None):
     # any sense anyway.
     sub_arguments = set(arguments[:arity])
     pe = PartExtracter(sub_arguments)
+
     def _transform(e):
         e, provides = pe.visit(e)
         if provides == sub_arguments:
@@ -339,9 +340,9 @@ def compute_form_with_arity(form, arity, arguments=None):
         return Zero()
     return map_integrands(_transform, form)
 
+
 def compute_form_arities(form):
     """Return set of arities of terms present in form."""
-    #ufl_assert(form.is_preprocessed(), "Assuming a preprocessed form.")
 
     # Extract all arguments present in form
     arguments = form.arguments()
@@ -362,6 +363,7 @@ def compute_form_arities(form):
 
     return arities
 
+
 def compute_form_lhs(form):
     """Compute the left hand side of a form.
 
@@ -372,6 +374,7 @@ def compute_form_lhs(form):
     """
     return compute_form_with_arity(form, 2)
 
+
 def compute_form_rhs(form):
     """Compute the right hand side of a form.
 
@@ -382,6 +385,7 @@ def compute_form_rhs(form):
     """
     return -compute_form_with_arity(form, 1)
 
+
 def compute_form_functional(form):
     """Compute the functional part of a form, that
     is the terms independent of Arguments.
@@ -389,6 +393,7 @@ def compute_form_functional(form):
     (Used for testing, not sure if it's useful for anything?)"""
     return compute_form_with_arity(form, 0)
 
+
 def compute_form_action(form, coefficient):
     """Compute the action of a form on a Coefficient.
 
@@ -410,14 +415,13 @@ def compute_form_action(form, coefficient):
     # Pick last argument (will be replaced)
     u = arguments[-1]
 
-    e = u.element()
+    fs = u.ufl_function_space()
     if coefficient is None:
-        coefficient = Coefficient(e)
-    else:
-        #ufl_assert(coefficient.element() == e, \
-        if coefficient.element() != e:
-            debug("Computing action of form on a coefficient in a different element space.")
-    return replace(form, { u: coefficient })
+        coefficient = Coefficient(fs)
+    elif coefficient.ufl_function_space() != fs:
+        debug("Computing action of form on a coefficient in a different function space.")
+    return replace(form, {u: coefficient})
+
 
 def compute_energy_norm(form, coefficient):
     """Compute the a-norm of a Coefficient given a form a.
@@ -434,18 +438,21 @@ def compute_energy_norm(form, coefficient):
     if set(parts) - {None}:
         error("compute_energy_norm cannot handle parts.")
 
-    ufl_assert(len(arguments) == 2, "Expecting bilinear form.")
+    if len(arguments) != 2:
+        error("Expecting bilinear form.")
     v, u = arguments
-    e = u.element()
-    e2 = v.element()
-    ufl_assert(e == e2, "Expecting equal finite elements for test and trial functions, got '%s' and '%s'." % (str(e), str(e2)))
+    U = u.ufl_function_space()
+    V = v.ufl_function_space()
+    if U != V:
+        error("Expecting equal finite elements for test and trial functions, got '%s' and '%s'." % (U, V))
     if coefficient is None:
-        coefficient = Coefficient(e)
+        coefficient = Coefficient(V)
     else:
-        ufl_assert(coefficient.element() == e, \
-            "Trying to compute action of form on a "\
-            "coefficient in an incompatible element space.")
-    return replace(form, { u: coefficient, v: coefficient })
+        if coefficient.ufl_function_space() != U:
+            error("Trying to compute action of form on a "
+                  "coefficient in an incompatible element space.")
+    return replace(form, {u: coefficient, v: coefficient})
+
 
 def compute_form_adjoint(form, reordered_arguments=None):
     """Compute the adjoint of a bilinear form.
@@ -459,28 +466,32 @@ def compute_form_adjoint(form, reordered_arguments=None):
     if set(parts) - {None}:
         error("compute_form_adjoint cannot handle parts.")
 
-    ufl_assert(len(arguments) == 2, "Expecting bilinear form.")
+    if len(arguments) != 2:
+        error("Expecting bilinear form.")
 
     v, u = arguments
-    ufl_assert(v.number() < u.number(), "Mistaken assumption in code!")
+    if v.number() >= u.number():
+        error("Mistaken assumption in code!")
 
     if reordered_arguments is None:
-        reordered_u = u.reconstruct(number=v.number(), part=v.part())
-        reordered_v = v.reconstruct(number=u.number(), part=u.part())
+        reordered_u = Argument(u.ufl_function_space(), number=v.number(),
+                               part=v.part())
+        reordered_v = Argument(v.ufl_function_space(), number=u.number(),
+                               part=u.part())
     else:
         reordered_u, reordered_v = reordered_arguments
 
-    ufl_assert(reordered_u.number() < reordered_v.number(),
-               "Ordering of new arguments is the same as the old arguments!")
+    if reordered_u.number() >= reordered_v.number():
+        error("Ordering of new arguments is the same as the old arguments!")
 
-    ufl_assert(reordered_u.part() == v.part(),
-               "Ordering of new arguments is the same as the old arguments!")
-    ufl_assert(reordered_v.part() == u.part(),
-               "Ordering of new arguments is the same as the old arguments!")
+    if reordered_u.part() != v.part():
+        error("Ordering of new arguments is the same as the old arguments!")
+    if reordered_v.part() != u.part():
+        error("Ordering of new arguments is the same as the old arguments!")
 
-    ufl_assert(reordered_u.element() == u.element(),
-               "Element mismatch between new and old arguments (trial functions).")
-    ufl_assert(reordered_v.element() == v.element(),
-               "Element mismatch between new and old arguments (test functions).")
+    if reordered_u.ufl_function_space() != u.ufl_function_space():
+        error("Element mismatch between new and old arguments (trial functions).")
+    if reordered_v.ufl_function_space() != v.ufl_function_space():
+        error("Element mismatch between new and old arguments (test functions).")
 
     return replace(form, {v: reordered_v, u: reordered_u})
