@@ -1,10 +1,12 @@
+# -*- coding: utf-8 -*-
+# flake8: noqa
 """This file is useful for external code like tests and form compilers,
 since it enables the syntax "from ufl.classes import CellFacetooBar" for getting
 implementation details not exposed through the default ufl namespace.
 It also contains functionality used by algorithms for dealing with groups
 of classes, and for mapping types to different handler functions."""
 
-# Copyright (C) 2008-2014 Martin Sandve Alnes
+# Copyright (C) 2008-2016 Martin Sandve Alnæs
 #
 # This file is part of UFL.
 #
@@ -25,15 +27,13 @@ of classes, and for mapping types to different handler functions."""
 # Modified by Kristian B. Oelgaard, 2011
 # Modified by Andrew T. T. McRae, 2014
 
-
 # This will be populated part by part below
 __all__ = []
 
+from ufl.utils.py23 import as_native_strings
 
-#
-# Import all submodules, triggering execution of the
-# ufl_type class decorator for each Expr class.
-#
+# Import all submodules, triggering execution of the ufl_type class
+# decorator for each Expr class.
 
 # Base classes of Expr type hierarchy
 import ufl.core.expr
@@ -45,7 +45,6 @@ import ufl.constantvalue
 import ufl.argument
 import ufl.coefficient
 import ufl.geometry
-import ufl.indexing
 
 # Operator types
 import ufl.indexed
@@ -61,19 +60,17 @@ import ufl.restriction
 import ufl.exprcontainers
 import ufl.referencevalue
 
-# Make sure we import exproperators which attaches special functions to Expr
+# Make sure we import exproperators which attaches special functions
+# to Expr
 from ufl import exproperators as __exproperators
 
-
-#
 # Make sure to import modules with new Expr subclasses here!
-#
 
 # Collect all classes in sets automatically classified by some properties
-all_ufl_classes     = set(ufl.core.expr.Expr._ufl_all_classes_)
-abstract_classes    = set(c for c in all_ufl_classes if c._ufl_is_abstract_)
-ufl_classes         = set(c for c in all_ufl_classes if not c._ufl_is_abstract_)
-terminal_classes    = set(c for c in all_ufl_classes if c._ufl_is_terminal_)
+all_ufl_classes = set(ufl.core.expr.Expr._ufl_all_classes_)
+abstract_classes = set(c for c in all_ufl_classes if c._ufl_is_abstract_)
+ufl_classes = set(c for c in all_ufl_classes if not c._ufl_is_abstract_)
+terminal_classes = set(c for c in all_ufl_classes if c._ufl_is_terminal_)
 nonterminal_classes = set(c for c in all_ufl_classes if not c._ufl_is_terminal_)
 
 __all__ += [
@@ -82,7 +79,8 @@ __all__ += [
     "ufl_classes",
     "terminal_classes",
     "nonterminal_classes",
-    ]
+]
+
 
 def populate_namespace_with_expr_classes(namespace):
     """Export all Expr subclasses into the namespace under their natural name."""
@@ -94,51 +92,49 @@ def populate_namespace_with_expr_classes(namespace):
         names.append(class_name)
     return names
 
+
 __all__ += populate_namespace_with_expr_classes(locals())
 
-# Domain types
-from ufl.cell import Cell, ProductCell, OuterProductCell
-from ufl.domain import Domain, ProductDomain
 
-__all__ += [
-    "Cell", "ProductCell", "OuterProductCell",
-    "Domain", "ProductDomain",
-    ]
+# Semi-automated imports of non-expr classes:
 
-# Elements
-from ufl.finiteelement import (
-    FiniteElementBase,
-    FiniteElement,
-    MixedElement, VectorElement, TensorElement,
-    EnrichedElement, RestrictedElement,
-    TensorProductElement, OuterProductElement, OuterProductVectorElement)
+def populate_namespace_with_module_classes(mod, loc):
+    """Export the classes that submodules list in __all_classes__."""
+    names = mod.__all_classes__
+    for name in names:
+        loc[name] = getattr(mod, name)
+    return names
 
-__all__ += [
-    "FiniteElementBase",
-    "FiniteElement",
-    "MixedElement", "VectorElement", "TensorElement",
-    "EnrichedElement", "RestrictedElement",
-    "TensorProductElement", "OuterProductElement", "OuterProductVectorElement",
-    ]
 
-# Other non-Expr types
-from ufl.argument import TestFunction, TrialFunction, TestFunctions, TrialFunctions
-from ufl.core.multiindex import IndexBase, FixedIndex, Index
+import ufl.cell  # noqa E401
+__all__ += populate_namespace_with_module_classes(ufl.cell, locals())
 
-__all__ += [
-    "TestFunction", "TrialFunction", "TestFunctions", "TrialFunctions",
-    "IndexBase", "FixedIndex", "Index",
-    ]
+import ufl.finiteelement  # noqa E401
+__all__ += populate_namespace_with_module_classes(ufl.finiteelement, locals())
 
-# Higher level abstractions
-from ufl.measure import Measure, MeasureSum, MeasureProduct
-from ufl.integral import Integral
-from ufl.form import Form
-from ufl.equation import Equation
+import ufl.domain  # noqa E401
+__all__ += populate_namespace_with_module_classes(ufl.domain, locals())
 
-__all__ += [
-    "Measure", "MeasureSum", "MeasureProduct",
-    "Integral",
-    "Form",
-    "Equation",
-    ]
+import ufl.functionspace  # noqa E401
+__all__ += populate_namespace_with_module_classes(ufl.functionspace, locals())
+
+import ufl.core.multiindex  # noqa E401
+__all__ += populate_namespace_with_module_classes(ufl.core.multiindex, locals())
+
+import ufl.argument  # noqa E401
+__all__ += populate_namespace_with_module_classes(ufl.argument, locals())
+
+import ufl.measure  # noqa E401
+__all__ += populate_namespace_with_module_classes(ufl.measure, locals())
+
+import ufl.integral  # noqa E401
+__all__ += populate_namespace_with_module_classes(ufl.integral, locals())
+
+import ufl.form  # noqa E401
+__all__ += populate_namespace_with_module_classes(ufl.form, locals())
+
+import ufl.equation  # noqa E401
+__all__ += populate_namespace_with_module_classes(ufl.equation, locals())
+
+
+__all__ = as_native_strings(__all__)
