@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
-"""Base class for multifunctions with UFL Expr type dispatch."""
+"""Base class for multifunctions with UFL ``Expr`` type dispatch."""
 
-# Copyright (C) 2008-2015 Martin Sandve Alnæs
+# Copyright (C) 2008-2016 Martin Sandve Alnæs
 #
 # This file is part of UFL.
 #
@@ -17,18 +17,23 @@
 #
 # You should have received a copy of the GNU Lesser General Public License
 # along with UFL. If not, see <http://www.gnu.org/licenses/>.
+#
+# Modified by Massimiliano Leoni, 2016
 
 from inspect import getargspec
 
 from ufl.log import error
 from ufl.core.expr import Expr
 
+
 def get_num_args(function):
+    "Return the number of arguments accepted by *function*."
     insp = getargspec(function)
     return len(insp[0]) + int(insp[1] is not None)
 
+
 def memoized_handler(handler):
-    "Function decorator to memoize MultiFunction handlers."
+    "Function decorator to memoize ``MultiFunction`` handlers."
     def _memoized_handler(self, o):
         c = getattr(self, "_memoized_handler_cache")
         r = c.get(o)
@@ -38,16 +43,18 @@ def memoized_handler(handler):
         return r
     return _memoized_handler
 
+
 class MultiFunction(object):
-    """Base class for collections of nonrecursive expression node handlers.
+    """Base class for collections of non-recursive expression node handlers.
 
-    Subclass this (remember to call the __init__ method of this class),
-    and implement handler functions for each Expr type, using the lower case
-    handler name of the type (exprtype._ufl_handler_name_).
+    Subclass this (remember to call the ``__init__`` method of this class),
+    and implement handler functions for each ``Expr`` type, using the lower case
+    handler name of the type (``exprtype._ufl_handler_name_``).
 
-    This class is optimized for efficient type based dispatch in the __call__
+    This class is optimized for efficient type based dispatch in the
+    ``__call__``
     operator via typecode based lookup of the handler function bound to the
-    algorithm object. Of course function call overhead of Python still applies.
+    algorithm object. Of course Python's function call overhead still applies.
     """
 
     _handlers_cache = {}
@@ -59,25 +66,30 @@ class MultiFunction(object):
         algorithm_class = type(self)
         cache_data = MultiFunction._handlers_cache.get(algorithm_class)
         if not cache_data:
-            cache_data = [None]*len(Expr._ufl_all_classes_)
+            handler_names = [None]*len(Expr._ufl_all_classes_)
 
-            # Iterate over the inheritance chain for each Expr subclass
-            # (NB! This assumes that all UFL classes inherits from
-            # a single Expr subclass and that the first superclass
-            # is always from the UFL Expr hierarchy!)
+            # Iterate over the inheritance chain for each Expr
+            # subclass (NB! This assumes that all UFL classes inherits
+            # from a single Expr subclass and that the first
+            # superclass is always from the UFL Expr hierarchy!)
             for classobject in Expr._ufl_all_classes_:
                 for c in classobject.mro():
-                    # Register classobject with handler for the first encountered superclass
-                    name = c._ufl_handler_name_
-                    if hasattr(self, name):
-                        cache_data[classobject._ufl_typecode_] = name
+                    # Register classobject with handler for the first
+                    # encountered superclass
+                    handler_name = c._ufl_handler_name_
+                    if hasattr(self, handler_name):
+                        handler_names[classobject._ufl_typecode_] = handler_name
                         break
+            is_cutoff_type = [get_num_args(getattr(self, name)) == 2
+                              for name in handler_names]
+            cache_data = (handler_names, is_cutoff_type)
             MultiFunction._handlers_cache[algorithm_class] = cache_data
 
-        # Build handler list for this particular class
-        # (get functions bound to self, these cannot be cached)
-        self._handlers = [getattr(self, name) for name in cache_data]
-        self._is_cutoff_type = [get_num_args(h) == 2 for h in self._handlers]
+        # Build handler list for this particular class (get functions
+        # bound to self, these cannot be cached)
+        handler_names, is_cutoff_type = cache_data
+        self._handlers = [getattr(self, name) for name in handler_names]
+        self._is_cutoff_type = is_cutoff_type
 
         # Create cache for memoized_handler
         self._memoized_handler_cache = {}
@@ -94,6 +106,7 @@ class MultiFunction(object):
         """Reuse object if operands are the same objects.
 
         Use in your own subclass by setting e.g.
+        ::
 
             expr = MultiFunction.reuse_if_untouched
 
