@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 "The Equation class, used to express equations like a == L."
 
-# Copyright (C) 2012-2015 Anders Logg and Martin Sandve Alnæs
+# Copyright (C) 2012-2016 Anders Logg and Martin Sandve Alnæs
 #
 # This file is part of UFL.
 #
@@ -18,8 +18,13 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with UFL. If not, see <http://www.gnu.org/licenses/>.
 
+from ufl.log import error
+from ufl.utils.py23 import as_native_str
+from ufl.utils.py23 import as_native_strings
+
 # Export list for ufl.classes
-__all_classes__ = ["Equation"]
+__all_classes__ = as_native_strings(["Equation"])
+
 
 class Equation(object):
     """This class is used to represent equations expressed by the "=="
@@ -39,14 +44,17 @@ class Equation(object):
         """
         # NB!: pep8 will say you should use isinstance here, but we do
         #      actually want to compare the exact types in this case.
-        # Not equal if types are not identical (i.e. not accepting subclasses)
-        if type(self.lhs) != type(self.rhs):
+        # Not equal if types are not identical (i.e. not accepting
+        # subclasses)
+        if type(self.lhs) != type(self.rhs):  # noqa: E721
             return False
         # Try to delegate to equals function
         if hasattr(self.lhs, "equals"):
             return self.lhs.equals(self.rhs)
-        # Fall back to repr
-        return repr(self.lhs) == repr(self.rhs)
+        elif hasattr(self.rhs, "equals"):
+            return self.rhs.equals(self.lhs)
+        else:
+            error("Either lhs or rhs of Equation must implement self.equals(other).")
     __nonzero__ = __bool__
 
     def __eq__(self, other):
@@ -59,4 +67,5 @@ class Equation(object):
         return hash((hash(self.lhs), hash(self.rhs)))
 
     def __repr__(self):
-        return "Equation(%r, %r)" % (self.lhs, self.rhs)
+        r = "Equation(%s, %s)" % (repr(self.lhs), repr(self.rhs))
+        return as_native_str(r)
