@@ -1,6 +1,7 @@
+# -*- coding: utf-8 -*-
 """This module defines special types for representing mapping of expressions to expressions."""
 
-# Copyright (C) 2014 Martin Sandve Alnes
+# Copyright (C) 2014 Martin Sandve Alnæs
 #
 # This file is part of UFL.
 #
@@ -17,14 +18,14 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with UFL. If not, see <http://www.gnu.org/licenses/>.
 
-from ufl.log import error, warning
-from ufl.assertions import ufl_assert
-from ufl.common import EmptyDict
+from ufl.utils.py23 import as_native_str
+from ufl.log import error
 from ufl.core.expr import Expr
 from ufl.core.operator import Operator
 from ufl.core.ufl_type import ufl_type
 
-#--- Non-tensor types ---
+
+# --- Non-tensor types ---
 
 @ufl_type(num_ops="varying")
 class ExprList(Operator):
@@ -49,7 +50,8 @@ class ExprList(Operator):
         return "ExprList(*(%s,))" % ", ".join(str(i) for i in self.ufl_operands)
 
     def __repr__(self):
-        return "ExprList(*%r)" % (self.ufl_operands,)
+        r = "ExprList(*%s)" % repr(self.ufl_operands)
+        return as_native_str(r)
 
     @property
     def ufl_shape(self):
@@ -80,27 +82,29 @@ class ExprMapping(Operator):
         if not all(isinstance(e, Expr) for e in operands):
             error("Expecting Expr in ExprMapping.")
 
-    def domains(self):
-        # Because this type can act like a terminal if it has no operands, we need to override some recursive operations
+    def ufl_domains(self):
+        # Because this type can act like a terminal if it has no
+        # operands, we need to override some recursive operations
         if self.ufl_operands:
-            return Operator.domains()
+            return Operator.ufl_domains()
         else:
             return []
 
-    #def __getitem__(self, key):
-    #    return self.ufl_operands[key]
+    # def __getitem__(self, key):
+    #     return self.ufl_operands[key]
 
-    #def __len__(self):
-    #    return len(self.ufl_operands) // 2
+    # def __len__(self):
+    #     return len(self.ufl_operands) // 2
 
-    #def __iter__(self):
-    #    return iter(self.ufl_operands[::2])
+    # def __iter__(self):
+    #     return iter(self.ufl_operands[::2])
 
     def __str__(self):
-        return "ExprMapping(*%r)" % (self.ufl_operands,)
+        return "ExprMapping(*%s)" % repr(self.ufl_operands)
 
     def __repr__(self):
-        return "ExprMapping(*%r)" % (self.ufl_operands,)
+        r = "ExprMapping(*%s)" % repr(self.ufl_operands)
+        return as_native_str(r)
 
     @property
     def ufl_shape(self):
