@@ -31,7 +31,7 @@ from six.moves import xrange as range
 from ufl.log import error
 from ufl.utils.py23 import as_native_strings
 from ufl.permutation import compute_indices
-from ufl.utils.sequences import product
+from ufl.utils.sequences import product, max_degree
 from ufl.utils.dicts import EmptyDict
 from ufl.utils.indexflattening import flatten_multiindex, unflatten_index, shape_to_strides
 from ufl.cell import as_cell
@@ -101,7 +101,7 @@ class MixedElement(FiniteElementBase):
 
         # Initialize element data
         degrees = {e.degree() for e in self._sub_elements} - {None}
-        degree = max(degrees) if degrees else None
+        degree = max_degree(degrees) if degrees else None
         FiniteElementBase.__init__(self, "Mixed", cell, degree, quad_scheme,
                                    value_shape, reference_value_shape)
 
@@ -245,6 +245,9 @@ class MixedElement(FiniteElementBase):
             i, e = self.extract_component(component)
             return e.degree()
 
+    def reconstruct(self, **kwargs):
+        return MixedElement(*[e.reconstruct(**kwargs) for e in self.sub_elements()])
+
     def __str__(self):
         "Format as string for pretty printing."
         tmp = ", ".join(str(element) for element in self._sub_elements)
@@ -313,12 +316,15 @@ class VectorElement(MixedElement):
         self._family = sub_element.family()
         self._degree = sub_element.degree()
         self._sub_element = sub_element
-        self._form_degree = form_degree  # Storing for signature_data, not sure if it's needed
 
         # Cache repr string
         self._repr = "VectorElement(%s, dim=%d)" % (
             repr(sub_element), len(self._sub_elements))
 
+    def reconstruct(self, **kwargs):
+        sub_element = self._sub_element.reconstruct(**kwargs)
+        return VectorElement(sub_element, dim=len(self.sub_elements()))
+
     def __str__(self):
         "Format as string for pretty printing."
         return ("<vector element with %d components of %s>" %
@@ -332,10 +338,14 @@ class VectorElement(MixedElement):
 
 # @six.python_2_unicode_compatible
 class TensorElement(MixedElement):
-    "A special case of a mixed finite element where all elements are equal."
+    """A special case of a mixed finite element where all elements are
+    equal.
+
+    """
     __slots__ = as_native_strings(("_sub_element", "_shape", "_symmetry",
-                 "_sub_element_mapping", "_flattened_sub_element_mapping",
-                 "_mapping"))
+                                   "_sub_element_mapping",
+                                   "_flattened_sub_element_mapping",
+                                   "_mapping"))
 
     def __init__(self, family, cell=None, degree=None, shape=None,
                  symmetry=None, quad_scheme=None):
@@ -357,7 +367,7 @@ class TensorElement(MixedElement):
             if cell is not None:
                 cell = as_cell(cell)
             # Create scalar sub element
-            sub_element = FiniteElement(family, cell, degree, quad_scheme)
+            sub_element = FiniteElement(family, cell, degree, quad_scheme=quad_scheme)
 
         if sub_element.value_shape() != ():
             error("Expecting only scalar valued subelement for TensorElement.")
@@ -386,8 +396,7 @@ class TensorElement(MixedElement):
             if len(i) != len(j):
                 error("Non-matching length of symmetry index tuples.")
             for k in range(len(i)):
-                if not (i[k] >= 0 and j[k] >= 0
-                        and i[k] < shape[k] and j[k] < shape[k]):
+                if not (i[k] >= 0 and j[k] >= 0 and i[k] < shape[k] and j[k] < shape[k]):
                     error("Symmetry dimensions out of bounds.")
 
         # Compute all index combinations for given shape
@@ -455,7 +464,7 @@ class TensorElement(MixedElement):
         self._check_component(i)
 
         i = self.symmetry().get(i, i)
-        l = len(self._shape)
+        l = len(self._shape)  # noqa: E741
         ii = i[:l]
         jj = i[l:]
         if ii not in self._sub_element_mapping:
@@ -470,6 +479,10 @@ class TensorElement(MixedElement):
         A component is a tuple of one or more ints."""
         return self._symmetry
 
+    def reconstruct(self, **kwargs):
+        sub_element = self._sub_element.reconstruct(**kwargs)
+        return TensorElement(sub_element, shape=self._shape, symmetry=self._symmetry)
+
     def __str__(self):
         "Format as string for pretty printing."
         if self._symmetry:
