@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 "This module defines basic utilities for stitching together LaTeX documents."
 
-# Copyright (C) 2008-2015 Martin Sandve Alnæs
+# Copyright (C) 2008-2016 Martin Sandve Alnæs
 #
 # This file is part of UFL.
 #
@@ -18,6 +18,8 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with UFL. If not, see <http://www.gnu.org/licenses/>.
 
+from six import string_types
+
 # --- Basic LaTeX tools ---
 
 documenttemplate = """\
@@ -66,12 +68,14 @@ verbatimtemplate = """\
 \\end{verbatim}
 """
 
+
 def verbatim(string):
     return verbatimtemplate % string
 
+
 def align(lines):
     # Calculate column lengths
-    if isinstance(lines[0], str):
+    if isinstance(lines[0], string_types):
         body = " \\\\\n".join(l for l in lines)
     else:
         n = len(lines[0])
@@ -79,17 +83,20 @@ def align(lines):
         for l in lines:
             for i, s in enumerate(l):
                 collengths[i] = max(collengths[i], len(s))
+
         def coljoin(cols):
             return " & ".join(c.ljust(collengths[i]) for (i, c) in enumerate(cols))
         body = " \\\\\n".join(coljoin(l) for l in lines)
     return aligntemplate % body
 
+
 def itemize(items):
     body = "\n".join(items)
     return itemizetemplate % body
 
+
 def subsubsection(s):
-    if isinstance(s, str):
+    if isinstance(s, string_types):
         return s
     if isinstance(s, tuple):
         title, body = s
@@ -97,8 +104,9 @@ def subsubsection(s):
             body = itemize(list(map(str, body)))
         return subsubsectiontemplate % (title, body)
 
+
 def subsection(s):
-    if isinstance(s, str):
+    if isinstance(s, string_types):
         return s
     if isinstance(s, tuple):
         title, body = s
@@ -106,8 +114,9 @@ def subsection(s):
             body = "\n".join(subsubsection(ss) for ss in body)
         return subsectiontemplate % (title, body)
 
+
 def section(s):
-    if isinstance(s, str):
+    if isinstance(s, string_types):
         return s
     if isinstance(s, tuple):
         title, body = s
@@ -115,10 +124,12 @@ def section(s):
             body = "\n".join(subsection(ss) for ss in body)
         return sectiontemplate % (title, body)
 
+
 def document(title, sections):
     body = "\n".join(section(s) for s in sections)
     return documenttemplate % (title, body)
 
+
 def testdocument():
     title = "Test title 1"
     sections = ["sec1", "sec2"]
@@ -135,8 +146,7 @@ def testdocument():
     sections = [("sec1", section1), ("sec2", section2), ("sec3", section3)]
     print(document(title, sections))
 
-    matrix = [ ("a(...) ", "= \\int_\\Omega foo dx0"),
-               ("",        "+ \\int_\\Omega foo dx1"),
-               ("",        "+ \\int_\\Omega foo dx1"),
-            ]
+    matrix = [("a(...) ", "= \\int_\\Omega foo dx0"),
+              ("", "+ \\int_\\Omega foo dx1"),
+              ("", "+ \\int_\\Omega foo dx1"), ]
     print(align(matrix))
