@@ -2,7 +2,7 @@
 """A collection of utility algorithms for printing
 of UFL objects, mostly intended for debugging purposes."""
 
-# Copyright (C) 2008-2015 Martin Sandve Alnæs
+# Copyright (C) 2008-2016 Martin Sandve Alnæs
 #
 # This file is part of UFL.
 #
@@ -21,43 +21,39 @@ of UFL objects, mostly intended for debugging purposes."""
 #
 # Modified by Anders Logg 2009, 2014
 
-from itertools import chain
-
 from ufl.log import error
-from ufl.assertions import ufl_assert
 from ufl.core.expr import Expr
-from ufl.core.terminal import Terminal
 from ufl.form import Form
-from ufl.integral import Integral, Measure
+from ufl.integral import Integral
 
-#--- Utilities for constructing informative strings from UFL objects ---
+
+# --- Utilities for constructing informative strings from UFL objects
 
 def integral_info(integral):
-    ufl_assert(isinstance(integral, Integral), "Expecting an Integral.")
-    s  = "  Integral:\n"
+    if not isinstance(integral, Integral):
+        error("Expecting an Integral.")
+    s = "  Integral:\n"
     s += "    Type:\n"
     s += "      %s\n" % integral.integral_type()
     s += "    Domain:\n"
-    s += "      %r\n" % integral.ufl_domain()
+    s += "      %s\n" % integral.ufl_domain()
     s += "    Domain id:\n"
-    s += "      %r\n" % integral.subdomain_id()
+    s += "      %s\n" % integral.subdomain_id()
     s += "    Domain data:\n"
     s += "      %s\n" % integral.subdomain_data()
     s += "    Compiler metadata:\n"
     s += "      %s\n" % integral.metadata()
-    s += "    Integrand expression representation:\n"
-    s += "      %r\n" % integral.integrand()
-    s += "    Integrand expression short form:\n"
-    s += "      %s" % integral.integrand()
     return s
 
+
 def form_info(form):
-    ufl_assert(isinstance(form, Form), "Expecting a Form.")
+    if not isinstance(form, Form):
+        error("Expecting a Form.")
 
     bf = form.arguments()
     cf = form.coefficients()
 
-    s  = "Form info:\n"
+    s = "Form info:\n"
     s += "  rank:                          %d\n" % len(bf)
     s += "  num_coefficients:              %d\n" % len(cf)
     s += "\n"
@@ -83,23 +79,26 @@ def form_info(form):
 
     return s
 
+
 def _indent_string(n):
     return "    "*n
 
+
 def _tree_format_expression(expression, indentation, parentheses):
     ind = _indent_string(indentation)
     if expression._ufl_is_terminal_:
-        s = ind + "%s" % repr(expression)
+        s = "%s%s" % (ind, repr(expression))
     else:
         sops = [_tree_format_expression(o, indentation+1, parentheses) for o in expression.ufl_operands]
-        s = ind + "%s\n" % expression._ufl_class_.__name__
+        s = "%s%s\n" % (ind, expression._ufl_class_.__name__)
         if parentheses and len(sops) > 1:
-            s += ind + "(\n"
+            s += "%s(\n" % (ind,)
         s += "\n".join(sops)
         if parentheses and len(sops) > 1:
-            s += "\n" + ind + ")"
+            s += "\n%s)" % (ind,)
     return s
 
+
 def tree_format(expression, indentation=0, parentheses=True):
     s = ""
 
