@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 "Various high level ways to transform a complete Form into a new Form."
 
-# Copyright (C) 2008-2015 Martin Sandve Alnæs
+# Copyright (C) 2008-2016 Martin Sandve Alnæs
 #
 # This file is part of UFL.
 #
@@ -19,15 +19,15 @@
 # along with UFL. If not, see <http://www.gnu.org/licenses/>.
 #
 # Modified by Anders Logg, 2009
+# Modified by Massimiliano Leoni, 2016
 
 from six import iteritems
 from six.moves import zip
 from six.moves import xrange as range
 
 from ufl.log import error
-from ufl.assertions import ufl_assert
 from ufl.form import Form, as_form
-from ufl.core.expr import Expr
+from ufl.core.expr import Expr, ufl_err_str
 from ufl.split_functions import split
 from ufl.exprcontainers import ExprList, ExprMapping
 from ufl.variable import Variable
@@ -43,18 +43,15 @@ from ufl.sorting import sorted_expr
 from ufl.functionspace import FunctionSpace
 
 # An exception to the rule that ufl.* does not depend on ufl.algorithms.* ...
-from ufl.algorithms import compute_form_adjoint, \
-                           compute_form_action, \
-                           compute_energy_norm, \
-                           compute_form_lhs, \
-                           compute_form_rhs, \
-                           compute_form_functional, \
-                           expand_derivatives, \
-                           extract_arguments, \
-                           FormSplitter
+from ufl.algorithms import compute_form_adjoint, compute_form_action
+from ufl.algorithms import compute_energy_norm
+from ufl.algorithms import compute_form_lhs, compute_form_rhs, compute_form_functional
+from ufl.algorithms import expand_derivatives, extract_arguments
+from ufl.algorithms import FormSplitter
 
 # Part of the external interface
-from ufl.algorithms import replace
+from ufl.algorithms import replace  # noqa
+
 
 def block_split(form, ix, iy=0):
     """UFL form operator:
@@ -69,12 +66,13 @@ def block_split(form, ix, iy=0):
     fs = FormSplitter()
     return fs.split(form, ix, iy)
 
+
 def lhs(form):
     """UFL form operator:
     Given a combined bilinear and linear form,
     extract the left hand side (bilinear form part).
 
-    Example:
+    Example::
 
         a = u*v*dx + f*v*dx
         a = lhs(a) -> u*v*dx
@@ -83,12 +81,13 @@ def lhs(form):
     form = expand_derivatives(form)
     return compute_form_lhs(form)
 
+
 def rhs(form):
     """UFL form operator:
     Given a combined bilinear and linear form,
     extract the right hand side (negated linear form part).
 
-    Example:
+    Example::
 
         a = u*v*dx + f*v*dx
         L = rhs(a) -> -f*v*dx
@@ -97,16 +96,20 @@ def rhs(form):
     form = expand_derivatives(form)
     return compute_form_rhs(form)
 
+
 def system(form):
-    "UFL form operator: Split a form into the left hand side and right hand side, see lhs and rhs."
+    """UFL form operator: Split a form into the left hand side and right hand
+    side, see ``lhs`` and ``rhs``."""
     return lhs(form), rhs(form)
 
-def functional(form): # TODO: Does this make sense for anything other than testing?
+
+def functional(form):  # TODO: Does this make sense for anything other than testing?
     "UFL form operator: Extract the functional part of form."
     form = as_form(form)
     form = expand_derivatives(form)
     return compute_form_functional(form)
 
+
 def action(form, coefficient=None):
     """UFL form operator:
     Given a bilinear form, return a linear form
@@ -117,35 +120,40 @@ def action(form, coefficient=None):
     form = expand_derivatives(form)
     return compute_form_action(form, coefficient)
 
+
 def energy_norm(form, coefficient=None):
     """UFL form operator:
-    Given a bilinear form a and a coefficient f,
-    return the functional a(f,f)."""
+    Given a bilinear form *a* and a coefficient *f*,
+    return the functional :math:`a(f,f)`."""
     form = as_form(form)
     form = expand_derivatives(form)
     return compute_energy_norm(form, coefficient)
 
+
 def adjoint(form, reordered_arguments=None):
     """UFL form operator:
     Given a combined bilinear form, compute the adjoint form by
     changing the ordering (count) of the test and trial functions.
 
-    By default, new Argument objects will be created with
+    By default, new ``Argument`` objects will be created with
     opposite ordering. However, if the adjoint form is to
     be added to other forms later, their arguments must match.
-    In that case, the user must provide a tuple reordered_arguments=(u2,v2).
+    In that case, the user must provide a tuple *reordered_arguments*=(u2,v2).
     """
     form = as_form(form)
     form = expand_derivatives(form)
     return compute_form_adjoint(form, reordered_arguments)
 
+
 def zero_lists(shape):
-    ufl_assert(len(shape) > 0, "Invalid shape.")
-    if len(shape) == 1:
+    if len(shape) == 0:
+        error("Invalid shape.")
+    elif len(shape) == 1:
         return [0]*shape[0]
     else:
         return [zero_lists(shape[1:]) for i in range(shape[0])]
 
+
 def set_list_item(li, i, v):
     # Get to the innermost list
     if len(i) > 1:
@@ -154,6 +162,7 @@ def set_list_item(li, i, v):
     # Set item in innermost list
     li[i[-1]] = v
 
+
 def _handle_derivative_arguments(form, coefficient, argument):
     # Wrap single coefficient in tuple for uniform treatment below
     if isinstance(coefficient, (list, tuple, ListTensor)):
@@ -166,19 +175,23 @@ def _handle_derivative_arguments(form, coefficient, argument):
         if not all(isinstance(c, Coefficient) for c in coefficients):
             error("Can only create arguments automatically for non-indexed coefficients.")
 
-        # Get existing arguments from form and position the new one with the next argument number
+        # Get existing arguments from form and position the new one
+        # with the next argument number
         if isinstance(form, Form):
             form_arguments = form.arguments()
         else:
-            # To handle derivative(expression), which is at least used in tests. Remove?
+            # To handle derivative(expression), which is at least used
+            # in tests. Remove?
             form_arguments = extract_arguments(form)
 
         numbers = sorted(set(arg.number() for arg in form_arguments))
         number = max(numbers + [-1]) + 1
 
-        # Don't know what to do with parts, let the user sort it out in that case
+        # Don't know what to do with parts, let the user sort it out
+        # in that case
         parts = set(arg.part() for arg in form_arguments)
-        ufl_assert(len(parts - {None}) == 0, "Not expecting parts here, provide your own arguments.")
+        if len(parts - {None}) != 0:
+            error("Not expecting parts here, provide your own arguments.")
         part = None
 
         # Create argument and split it if in a mixed space
@@ -210,15 +223,18 @@ def _handle_derivative_arguments(form, coefficient, argument):
     # Build mapping from coefficient to argument
     m = {}
     for (c, a) in zip(coefficients, arguments):
-        ufl_assert(c.ufl_shape == a.ufl_shape, "Coefficient and argument shapes do not match!")
+        if c.ufl_shape != a.ufl_shape:
+            error("Coefficient and argument shapes do not match!")
         if isinstance(c, Coefficient):
             m[c] = a
         else:
-            ufl_assert(isinstance(c, Indexed), "Invalid coefficient type for %s" % repr(c))
+            if not isinstance(c, Indexed):
+                error("Invalid coefficient type for %s" % ufl_err_str(c))
             f, i = c.ufl_operands
-            ufl_assert(isinstance(f, Coefficient), "Expecting an indexed coefficient, not %s" % repr(f))
-            ufl_assert(isinstance(i, MultiIndex) and all(isinstance(j, FixedIndex) for j in i),
-                       "Expecting one or more fixed indices, not %s" % repr(i))
+            if not isinstance(f, Coefficient):
+                error("Expecting an indexed coefficient, not %s" % ufl_err_str(f))
+            if not (isinstance(i, MultiIndex) and all(isinstance(j, FixedIndex) for j in i)):
+                error("Expecting one or more fixed indices, not %s" % ufl_err_str(i))
             i = tuple(int(j) for j in i)
             if f not in m:
                 m[f] = {}
@@ -238,30 +254,33 @@ def _handle_derivative_arguments(form, coefficient, argument):
     arguments = ExprList(*[item[1] for item in items])
     return coefficients, arguments
 
+
 def derivative(form, coefficient, argument=None, coefficient_derivatives=None):
     """UFL form operator:
-    Compute the Gateaux derivative of form w.r.t. coefficient in direction of argument.
+    Compute the Gateaux derivative of *form* w.r.t. *coefficient* in direction
+    of *argument*.
 
-    If the argument is omitted, a new Argument is created
+    If the argument is omitted, a new ``Argument`` is created
     in the same space as the coefficient, with argument number
     one higher than the highest one in the form.
 
-    The resulting form has one additional Argument
+    The resulting form has one additional ``Argument``
     in the same finite element space as the coefficient.
 
-    A tuple of Coefficients may be provided in place of
-    a single Coefficient, in which case the new Argument
-    argument is based on a MixedElement created from this tuple.
+    A tuple of ``Coefficient`` s may be provided in place of
+    a single ``Coefficient``, in which case the new ``Argument``
+    argument is based on a ``MixedElement`` created from this tuple.
 
-    An indexed Coefficient from a mixed space may be provided,
+    An indexed ``Coefficient`` from a mixed space may be provided,
     in which case the argument should be in the corresponding
     subspace of the coefficient space.
 
-    If provided, coefficient_derivatives should be a mapping from
-    Coefficient instances to their derivatives w.r.t. 'coefficient'.
+    If provided, *coefficient_derivatives* should be a mapping from
+    ``Coefficient`` instances to their derivatives w.r.t. *coefficient*.
     """
 
-    coefficients, arguments = _handle_derivative_arguments(form, coefficient, argument)
+    coefficients, arguments = _handle_derivative_arguments(form, coefficient,
+                                                           argument)
 
     if coefficient_derivatives is None:
         coefficient_derivatives = ExprMapping()
@@ -287,57 +306,69 @@ def derivative(form, coefficient, argument=None, coefficient_derivatives=None):
 
     error("Invalid argument type %s." % str(type(form)))
 
+
 def sensitivity_rhs(a, u, L, v):
     """UFL form operator:
     Compute the right hand side for a sensitivity calculation system.
 
     The derivation behind this computation is as follows.
-    Assume a, L to be bilinear and linear forms
+    Assume *a*, *L* to be bilinear and linear forms
     corresponding to the assembled linear system
 
+    .. math::
+
         Ax = b.
 
-    Where x is the vector of the discrete function corresponding to u.
-    Let v be some scalar variable this equation depends on.
+    Where *x* is the vector of the discrete function corresponding to *u*.
+    Let *v* be some scalar variable this equation depends on.
     Then we can write
 
-        0 = d/dv[Ax-b] = dA/dv x + A dx/dv - db/dv,
-        A dx/dv = db/dv - dA/dv x,
+    .. math::
+        0 = \\frac{d}{dv}(Ax-b) = \\frac{dA}{dv} x + A \\frac{dx}{dv} -
+        \\frac{db}{dv},
 
-    and solve this system for dx/dv, using the same bilinear form a
-    and matrix A from the original system.
+        A \\frac{dx}{dv} = \\frac{db}{dv} - \\frac{dA}{dv} x,
+
+    and solve this system for :math:`\\frac{dx}{dv}`, using the same bilinear
+    form *a* and matrix *A* from the original system.
     Assume the forms are written
+    ::
 
         v = variable(v_expression)
         L = IL(v)*dx
         a = Ia(v)*dx
 
-    where IL and Ia are integrand expressions.
-    Define a Coefficient u representing the solution
-    to the equations. Then we can compute db/dv
-    and dA/dv from the forms
+    where ``IL`` and ``Ia`` are integrand expressions.
+    Define a ``Coefficient u`` representing the solution
+    to the equations. Then we can compute :math:`\\frac{db}{dv}`
+    and :math:`\\frac{dA}{dv}` from the forms
+    ::
 
         da = diff(a, v)
         dL = diff(L, v)
 
-    and the action of da on u by
+    and the action of ``da`` on ``u`` by
+    ::
 
         dau = action(da, u)
 
     In total, we can build the right hand side of the system
-    to compute du/dv with the single line
+    to compute :math:`\\frac{du}{dv}` with the single line
+    ::
 
         dL = diff(L, v) - action(diff(a, v), u)
 
-    or, using this function
+    or, using this function,
+    ::
 
         dL = sensitivity_rhs(a, u, L, v)
     """
-    msg = "Expecting (a, u, L, v), (bilinear form, function, linear form and scalar variable)."
-    ufl_assert(isinstance(a, Form), msg)
-    ufl_assert(isinstance(u, Coefficient), msg)
-    ufl_assert(isinstance(L, Form), msg)
-    ufl_assert(isinstance(v, Variable), msg)
-    ufl_assert(is_true_ufl_scalar(v), "Expecting scalar variable.")
+    if not (isinstance(a, Form) and
+            isinstance(u, Coefficient) and
+            isinstance(L, Form) and
+            isinstance(v, Variable)):
+        error("Expecting (a, u, L, v), (bilinear form, function, linear form and scalar variable).")
+    if not is_true_ufl_scalar(v):
+        error("Expecting scalar variable.")
     from ufl.operators import diff
     return diff(L, v) - action(diff(a, v), u)
