@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 """This module defines the IndexSum class."""
 
-# Copyright (C) 2008-2015 Martin Sandve Alnæs
+# Copyright (C) 2008-2016 Martin Sandve Alnæs
 #
 # This file is part of UFL.
 #
@@ -21,29 +21,33 @@
 from six.moves import xrange as range
 
 from ufl.log import error
-from ufl.assertions import ufl_assert
-from ufl.core.expr import Expr
-from ufl.core.operator import Operator
-from ufl.core.multiindex import Index, MultiIndex, as_multi_index
-from ufl.precedence import parstr
-from ufl.utils.dicts import EmptyDict
+from ufl.utils.py23 import as_native_strings
 from ufl.core.ufl_type import ufl_type
+from ufl.core.expr import Expr, ufl_err_str
+from ufl.core.operator import Operator
+from ufl.core.multiindex import MultiIndex
+from ufl.precedence import parstr
 from ufl.constantvalue import Zero
 
-#--- Sum over an index ---
+
+# --- Sum over an index ---
 
 @ufl_type(num_ops=2)
 class IndexSum(Operator):
-    __slots__ = ("_dimension", "ufl_free_indices", "ufl_index_dimensions")
+    __slots__ = as_native_strings((
+        "_dimension",
+        "ufl_free_indices",
+        "ufl_index_dimensions",
+    ))
 
     def __new__(cls, summand, index):
         # Error checks
         if not isinstance(summand, Expr):
-            error("Expecting Expr instance, not %s." % repr(summand))
+            error("Expecting Expr instance, got %s" % ufl_err_str(summand))
         if not isinstance(index, MultiIndex):
-            error("Expecting MultiIndex instance, not %s." % repr(index))
+            error("Expecting MultiIndex instance, got %s" % ufl_err_str(index))
         if len(index) != 1:
-            error("Expecting a single Index only.")
+            error("Expecting a single Index onlym got %d." % len(index))
 
         # Simplification to zero
         if isinstance(summand, Zero):
@@ -83,12 +87,11 @@ class IndexSum(Operator):
         tmp = 0
         for k in range(self._dimension):
             index_values.push(i, k)
-            tmp += self.ufl_operands[0].evaluate(x, mapping, component, index_values)
+            tmp += self.ufl_operands[0].evaluate(x, mapping, component,
+                                                 index_values)
             index_values.pop()
         return tmp
 
     def __str__(self):
-        return "sum_{%s} %s " % (str(self.ufl_operands[1]), parstr(self.ufl_operands[0], self))
-
-    def __repr__(self):
-        return "IndexSum(%r, %r)" % (self.ufl_operands[0], self.ufl_operands[1])
+        return "sum_{%s} %s " % (str(self.ufl_operands[1]),
+                                 parstr(self.ufl_operands[0], self))
