@@ -417,6 +417,8 @@ def curl(f):
     "UFL operator: Take the curl of *f*."
     f = as_ufl(f)
     return Curl(f)
+
+
 rot = curl
 
 
@@ -706,7 +708,7 @@ def exterior_derivative(f):
     else:
         try:
             element = f.ufl_element()
-        except:
+        except Exception:
             error("Unable to determine element from %s" % f)
 
     # Extract the family and the geometric dimension
