@@ -1,7 +1,8 @@
+# -*- coding: utf-8 -*-
 """This module provides utility functions for computing permutations
 and generating index lists."""
 
-# Copyright (C) 2008-2014 Anders Logg and Kent-Andre Mardal
+# Copyright (C) 2008-2016 Anders Logg and Kent-Andre Mardal
 #
 # This file is part of UFL.
 #
@@ -18,10 +19,11 @@ and generating index lists."""
 # You should have received a copy of the GNU Lesser General Public License
 # along with UFL. If not, see <http://www.gnu.org/licenses/>.
 #
-# Modified by Martin Alnes 2009-2014
+# Modified by Martin Alnæs 2009-2016
 
 from six.moves import xrange as range
 
+
 def compute_indices(shape):
     "Compute all index combinations for given shape"
     if len(shape) == 0:
@@ -33,18 +35,22 @@ def compute_indices(shape):
             indices.append((i,) + sub_index)
     return tuple(indices)
 
+
 # functional version:
 def compute_indices2(shape):
     "Compute all index combinations for given shape"
     return ((),) if len(shape) == 0 else tuple((i,) + sub_index for i in range(shape[0]) for sub_index in compute_indices2(shape[1:]))
 
+
 def build_component_numbering(shape, symmetry):
     """Build a numbering of components within the given value shape,
     taking into consideration a symmetry mapping which leaves the
     mapping noncontiguous. Returns a dict { component -> numbering }
-    and an ordered list of components [ numbering -> component ].
-    The dict contains all components while the list only contains
-    the ones not mapped by the symmetry mapping."""
+    and an ordered list of components [ numbering -> component ].  The
+    dict contains all components while the list only contains the ones
+    not mapped by the symmetry mapping.
+
+    """
     vi2si, si2vi = {}, []
     indices = compute_indices(shape)
     # Number components not in symmetry mapping
@@ -61,15 +67,18 @@ def build_component_numbering(shape, symmetry):
         assert vi2si[c] == k
     return vi2si, si2vi
 
-def compute_permutations(k, n, skip = None):
+
+def compute_permutations(k, n, skip=None):
     """Compute all permutations of k elements from (0, n) in rising order.
-    Any elements that are contained in the list skip are not included."""
+    Any elements that are contained in the list skip are not included.
+
+    """
     if k == 0:
         return []
     if skip is None:
         skip = []
     if k == 1:
-        return [(i,) for i in range(n) if not i in skip]
+        return [(i,) for i in range(n) if i not in skip]
     pp = compute_permutations(k - 1, n, skip)
     permutations = []
     for i in range(n):
@@ -80,9 +89,12 @@ def compute_permutations(k, n, skip = None):
                 permutations.append((i,) + p)
     return permutations
 
+
 def compute_permutation_pairs(j, k):
-    """Compute all permutations of j + k elements from (0, j + k) in rising
-    order within (0, j) and (j, j + k) respectively."""
+    """Compute all permutations of j + k elements from (0, j + k) in
+    rising order within (0, j) and (j, j + k) respectively.
+
+    """
     permutations = []
     pp0 = compute_permutations(j, j + k)
     for p0 in pp0:
@@ -91,6 +103,7 @@ def compute_permutation_pairs(j, k):
             permutations.append((p0, p1))
     return permutations
 
+
 def compute_sign(permutation):
     "Compute sign by sorting."
     sign = 1
@@ -105,6 +118,7 @@ def compute_sign(permutation):
                 return 0
     return sign
 
+
 def compute_order_tuples(k, n):
     "Compute all tuples of n integers such that the sum is k"
     if n == 1:
