@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 """Restriction operations."""
 
-# Copyright (C) 2008-2015 Martin Sandve Alnæs
+# Copyright (C) 2008-2016 Martin Sandve Alnæs
 #
 # This file is part of UFL.
 #
@@ -18,12 +18,12 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with UFL. If not, see <http://www.gnu.org/licenses/>.
 
-from ufl.log import error
 from ufl.core.operator import Operator
 from ufl.precedence import parstr
 from ufl.core.ufl_type import ufl_type
 
-#--- Restriction operators ---
+
+# --- Restriction operators ---
 
 @ufl_type(is_abstract=True,
           num_ops=1,
@@ -42,19 +42,19 @@ class Restricted(Operator):
         return self._side
 
     def evaluate(self, x, mapping, component, index_values):
-        return self.ufl_operands[0].evaluate(x, mapping, component, index_values)
+        return self.ufl_operands[0].evaluate(x, mapping, component,
+                                             index_values)
 
     def __str__(self):
         return "%s('%s')" % (parstr(self.ufl_operands[0], self), self._side)
 
-    def __repr__(self):
-        return "%s(%r)" % (self._ufl_class_.__name__, self.ufl_operands[0])
 
 @ufl_type(is_terminal_modifier=True)
 class PositiveRestricted(Restricted):
     __slots__ = ()
     _side = "+"
 
+
 @ufl_type(is_terminal_modifier=True)
 class NegativeRestricted(Restricted):
     __slots__ = ()
@@ -80,14 +80,12 @@ class CellAvg(Operator):
 
     def evaluate(self, x, mapping, component, index_values):
         "Performs an approximate symbolic evaluation, since we dont have a cell."
-        return self.ufl_operands[0].evaluate(x, mapping, component, index_values)
+        return self.ufl_operands[0].evaluate(x, mapping, component,
+                                             index_values)
 
     def __str__(self):
         return "cell_avg(%s)" % (self.ufl_operands[0],)
 
-    def __repr__(self):
-        return "CellAvg(%r)" % self.ufl_operands[0]
-
 
 # TODO: Place in a better file?
 @ufl_type(is_index_free=True,
@@ -112,6 +110,3 @@ class FacetAvg(Operator):
 
     def __str__(self):
         return "facet_avg(%s)" % (self.ufl_operands[0],)
-
-    def __repr__(self):
-        return "FacetAvg(%r)" % self.ufl_operands[0]
